// SPDX-License-Identifier: Unlicense
pragma solidity ^0.8.24;

import "./Reputation.sol";

struct Citation {
    int[2] weight;
    uint targetPostIndex;
}

struct Post {
    uint id;
    address sender;
    address author;
    string contentId;
    uint reputation;
    Citation[] citations;
}

contract Forum is Reputation {
    mapping(uint => Post) public posts;
    uint public postCount;

    event PostAdded(uint postIndex);

    function addPost(
        address author,
        string calldata contentId,
        Citation[] calldata citations
    ) external returns (uint postIndex) {
        postIndex = postCount++;
        Post storage post = posts[postIndex];
        post.author = author;
        post.sender = msg.sender;
        post.id = postIndex;
        post.contentId = contentId;
        for (uint i = 0; i < citations.length; i++) {
            post.citations.push(citations[i]);
        }
        emit PostAdded(postIndex);
    }

    function _onValidatePost(uint postIndex, uint amount) internal {
        Post storage post = posts[postIndex];
        post.reputation = amount;
        _update(address(this), post.author, amount);
    }

    function _propagateValue() internal {}
}
